from setuptools import setup

setup(
    name='cradl',
    version='0.0.1',
    description='',
    long_description='',
    url='https://www.cradl.ai',
    author='August Kvernmo',
    author_email='august@lucidtech.ai',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)